Skip to content
View in the app

A better way to browse. Learn more.

Armbian Community Forums

A full-screen app on your home screen with push notifications, badges and more.

To install this app on iOS and iPadOS
  1. Tap the Share icon in Safari
  2. Scroll the menu and tap Add to Home Screen.
  3. Tap Add in the top-right corner.
To install this app on Android
  1. Tap the 3-dot menu (⋮) in the top-right corner of the browser.
  2. Tap Add to Home screen or Install app.
  3. Confirm by tapping Install.

[Armbian build PR] - Update armbianmonitor

Featured Replies

Description

Previous help message

armbianmonitor -h
Usage: armbianmonitor [-h] [-b] [-c $path] [-d $device] [-D] [-m] [-p] [-r] [-u]

############################################################################

 Use armbianmonitor for the following tasks:

 armbianmonitor -c /path/to/test performs disk health/performance tests
 armbianmonitor -d monitors writes to $device
 armbianmonitor -D tries to upload debug disk info to improve armbianmonitor
 armbianmonitor -m provides simple CLI monitoring - scrolling output
 armbianmonitor -M provides simple CLI monitoring - fixed-line output
 armbianmonitor -n provides simple CLI network monitoring - scrolling output
 armbianmonitor -N provides simple CLI network monitoring - fixed-line output
 armbianmonitor -p tries to install cpuminer for performance measurements
 armbianmonitor -r tries to install RPi-Monitor
 armbianmonitor -u tries to upload armbian-hardware-monitor.log for support purposes
 armbianmonitor -v tries to verify installed package integrity
 armbianmonitor -z runs a quick 7-zip benchmark to estimate CPU performance

############################################################################

proposed change, attemts to follow the conventions commonly used for displaying a help message.

armbianmonitor.sh" -h

Usage: armbianmonitor.sh [-h] [-b] [-c $path] [-d $device] [-D] [-m] [-p] [-r] [-u]

Options:
  -c /path/to/test   Performs disk health/performance tests
  -d                 Monitors writes to $device
  -D                 Tries to upload debug disk info to improve armbianmonitor
  -m                 Provides simple CLI monitoring - scrolling output
  -M                 Provides simple CLI monitoring - fixed-line output
  -n                 Provides simple CLI network monitoring - scrolling output
  -N                 Provides simple CLI network monitoring - fixed-line output
  -p                 Tries to install cpuminer for performance measurements
  -r                 Tries to install RPi-Monitor
  -u                 Tries to upload armbian-hardware-monitor.log for support purposes
  -v                 Tries to verify installed package integrity
  -z                 Runs a quick 7-zip benchmark to estimate CPU performance

no expected chaneg in behavero other then help output funtions -z was tested

Checklist:

  • [ ??] My code follows the style guidelines of this project
  • [ Y] I have performed a self-review of my own code
  • [ Y] I have commented my code, particularly in hard-to-understand areas
  • [ NA] I have made corresponding changes to the documentation
  • [ No] My changes generate no new warnings
  • [ NA] Any dependent changes have been merged and published in downstream modules

View the full article

Account

Navigation

Search

Search

Configure browser push notifications

Chrome (Android)
  1. Tap the lock icon next to the address bar.
  2. Tap Permissions → Notifications.
  3. Adjust your preference.
Chrome (Desktop)
  1. Click the padlock icon in the address bar.
  2. Select Site settings.
  3. Find Notifications and adjust your preference.